@@ -13,12 +13,9 @@ logger = logging.getLogger(__name__)
 
 
 class BaseGrant(BaseModel):
-    ssl_context: SSLContext = Field(
-        default_factory=lambda: ssl.create_default_context(cafile=certifi.where())
-    )
 
     @abstractmethod
-    async def afetch_token(self, herre, **kwargs) -> Token:
+    async def afetch_token(self, force_refresh: bool =False) -> Token:
         raise NotImplementedError("Implement afetch_token")
 
     class Config:
