@@ -1,26 +1,13 @@
 from enum import Enum
 from typing import List, Optional
 from pydantic import BaseModel
-
+import time
 
 class GrantType(str, Enum):
     CLIENT_CREDENTIALS = "client-credentials"
     AUTHORIZATION_CODE = "authorization-code"
 
 
-class App(BaseModel):
-    clientID: Optional[str]
-    name: Optional[str]
-
-
-class User(BaseModel):
-    sub: str  # This is not optional as openid spec demands it
-    username: Optional[str]
-    email: Optional[str]
-    first_name: Optional[str]
-    last_name: Optional[str]
-
-
 class Token(BaseModel):
     access_token: str
     scope: Optional[List[str]]
@@ -28,3 +15,8 @@ class Token(BaseModel):
     expires_in: Optional[int]
     expires_at: Optional[int]
     token_type: Optional[str]
+
+    def is_expired(self) -> bool:
+        if self.expires_at:
+            return self.expires_at < int(time.time())
+        return False
